package physbeans.editors;

import java.util.*;
import java.awt.*;

/**
 * Property editor for boolean arrays.
 */
public class ArrayOfBooleanEditor extends java.beans.PropertyEditorSupport {
  
  /**
   * Returns a string that represents the current boolean array.
   */
  public String getAsText() {
    if (getValue() == null)
      return "null";
    
    boolean[] v = (boolean[]) getValue();
    int dim = v.length;
    
    String result = "[";
    for (int i=0; i<dim-1; i++) {
      result += v[i] + ",";
    }
    result += v[dim-1] + "]";
    
    return result;
  }
  
  /**
   * Reads the value of the property by parsing a string.
   */
  public void setAsText(String text) throws IllegalArgumentException {
    if (text.equals("null") || text.equals("")) {
      setValue(null);
      return;
    }
    
    boolean[] v = null;
    StringTokenizer toc = new StringTokenizer(text, "[] ,;");
    int dim = toc.countTokens();
    v = new boolean[dim];
    
    for (int i=0; i<dim; i++) {
      v[i] = Boolean.valueOf(toc.nextToken()).booleanValue();
    }
    
    setValue(v);
  }
  
  /**
   * Throws an exception if the text has a wrong format.
   */
  protected void wrongFormat(String text) throws IllegalArgumentException {
    throw new IllegalArgumentException("wrong format in " + text);
  }
  
  /**
   * Returns a string with java code that initializes a DVector.
   */
  public String getJavaInitializationString() {
    boolean[] v = (boolean[]) getValue();
    String result = "new boolean[]{";
    int dim = v.length;
    
    for (int i=0; i<dim - 1; i++) {
      result +=  v[i] + ",";
    }
    result += v[dim-1] + "}";
    
    return result;
  }
  
  /**
   * Returns true if a custom editor exists.
   */
  public boolean supportsCustomEditor() {
    return true;
  }
  
  /**
   * Returns an instance of a new custom editor.
   */
  public Component getCustomEditor() {
    return new ArrayOfBooleanCustomEditor(this);
  }
}
