package physbeans.editors;

import java.util.*;
import java.awt.*;
import java.beans.*;
import physbeans.math.*;

/**
 * Property editor for Matrix.
 */
public class MatrixEditor extends PropertyEditorSupport {
  
  /**
   * Returns a string that represents the current Matrix.
   */
  public String getAsText() {
    Matrix m = (Matrix) getValue();
    
    if (m == null) {
      return "null";
    } else {
      return m.toString();
    }
  }
  
  /**
   * Reads the value of the property by parsing a string.
   */
  public void setAsText(String text) throws IllegalArgumentException {
    if (text.equals("null") || text.equals("")) {
      setValue(null);
      return;
    }
    
    setValue(Matrix.valueOf(text));
  }
  
  /**
   * Returns a string with java code that initializes a Matrix.
   */
  public String getJavaInitializationString() {
    Matrix m = (Matrix) getValue();
    return "Matrix.valueOf(\"" + m.toString() + "\")";
  }
  
  /**
   * Returns true if a custom editor exists.
   */
  public boolean supportsCustomEditor() {
    return true;
  }
  
  /**
   * Returns an instance of a new custom editor.
   */
  public Component getCustomEditor() {
    return new MatrixCustomEditor(this);
  }
  
}
