package physbeans.func;

import physbeans.math.*;
import physbeans.event.*;

/**
 * Function that builds averages of each of its input values over time.
 * <P>Since it needs an internal buffer of constant size, the vector length can
 * not be set dynamically. After a restart the internal buffer is cleared
 * and the averaging process starts again.
 */
public class AveragingFunction extends GenericVectorFunction {
  
  int step;
  
  /**
   * Creates a default AveragingFunction.
   */
  public AveragingFunction() {
    super(1, 1, 2);
    step = 0;
  }
  
  /**
   * Computes the new values using the old values stored in outputValues.
   */
  protected void compute() {
    for (int i = 0; i < inputValues[0].getDimension(); i++) {
      outputValues[0].set(i, (step*outputValues[0].get(i) + inputValues[0].get(i))/(step + 1));
    }
    step++;
  }
  
  /**
   * Resets the internal buffer and starts averaging with the new arriving values.
   */
  public void restart() {
    step = 0;
    outputValues[0] = new DVector(inputValues[0].getDimension());
    fireVectorEvent(new VectorEvent(this, outputValues));
  }
  
}
