package physbeans.func;

import java.util.*;

/**
 * Base class of random vector functions.
 */
abstract public class RandomVector extends GenericVectorFunction {
  
  protected boolean randomize;
  protected Random rng;
  protected int seed;
  
  /** Creates a new instance of RandomVector */
  public RandomVector() {
    super(0,1,100);
    seed = 0;
    randomize = false;
    rng = new Random(seed);
  }
  
  /**
   * Gets seed to start the random generator.
   */
  public int getSeed() {
    return this.seed;
  }  
  
  /**
   * Gets randomize flag.
   * If true, current time is used for initialization of random generator.
   */
  public boolean isRandomize() {
    return this.randomize;
  }
  
    /**
   * Sets size of output vector.
   */
  public void setOutputSize(int n) {
    super.setOutputSize(n);
    if (autoTriggered) {
      trigger();
    }
  }
    
  /**
   * Sets randomize flag.
   * If true, current time is used for initialization of random generator.
   * In this case, the seed is ignored.
   */
  public void setRandomize(boolean randomize) {
    this.randomize = randomize;
    rng = new Random();
  } 
  
  /**
   * Sets seed to start the random generator.
   */
  public void setSeed(int seed) {
    this.seed = seed;
    rng = new Random(seed);
  }
  
}
