package physbeans.func;

import physbeans.math.*;
import physbeans.model.*;
import java.io.*;

/**
 * Periodic function describing a rectangular pulse of fixed area.
 * External parameter is the pulse width.
 */
public class SquareImpulseFunction extends PeriodicPiecewiseLinearFunction implements Serializable, PeriodicFunctionWithParameter {
  
  /** Holds value of property pulseWidth. */
  protected double pulseWidth;
  
  /** Creates a new instance of ImpulseFunction */
  public SquareImpulseFunction() {
    super();
    setPulseWidth(0.5);
  }
  
  /**
   * Gets the pulse width.
   * It is given as relative value, between 0 and 1.
   */
  public double getPulseWidth() {
    return pulseWidth;
  }
  
  /**
   * Sets the pulse width.
   * Input value is clamped to lie between 0 and 1.
   */
  public void setPulseWidth(double p) {
    if (p != 1.0) {
      p = p - Math.floor(p);
    }
    pulseWidth = p;
    setCornerPoints();
  }
  
  /*
   * compute corner points from pulse width and period.
   */
  protected void setCornerPoints() {
    x = new DVector(pulseWidth, pulseWidth);
    y = new DVector(1.0/(period*pulseWidth), 0);    
  }

  /**
   * Sets the period T.
   */
  public void setPeriod(double period) {
    super.setPeriod(period);
    setCornerPoints();  
  }
  
  /** 
   * Gets the parameter value.
   */
  public double getParameter() {
    return getPulseWidth();
  }
  
  /** 
   * Sets the parameter
   */
  public void setParameter(double p) {
    setPulseWidth(p);
  }
  
}
