package physbeans.phys;

import static physbeans.phys.Constants.*;
import static java.lang.Math.PI;

/**
 * Twodimensional Coulomb potential function.
 * It is given by
 *   V(x, y) = -Z e^2/(4 pi eps0) * 1/r
 * with
 *    Z     central charge in multiples of e
 */
public class Coulomb2DPotential extends Schroedinger2DPotential {

  protected double Z;
  protected double k;

  public Coulomb2DPotential() {
    super();
    Z = 1.0;
    k = Z * E0 * E0 / (4 * PI * EPSILON0);
  }

  public double getScalarValue(double x, double y) {
    return -k/Math.hypot(x, y);
  }

  /**
   * Sets the central charge (in multiples of e).
   */
  public void setZ(double Z) {
    this.Z = Z;
    k = Z * E0 * E0 / (4 * PI * EPSILON0);
    if (field != null) {
      field.computeCachedMatrices();
    }
  }

  /**
   * Gets the central charge (in multiples of e).
   */
  public double getZ() {
    return Z;
  }
}
