package physbeans.phys;

/**
 * Twodimensional potential function of a harmonic osciallator.
 * It is given by
 *   V(x, y) = 0.5*ME*om^2*(x^2 + y^2)
 * with
 *    ME     electron mass
 *    om     (circular) frequency of the potential
 */
public class Harmonic2DPotential extends Schroedinger2DPotential {

  protected double om;
  protected double me;

  public Harmonic2DPotential() {
    super();
    me = Constants.ME;
    om = 1.0e14;
  }

  public double getScalarValue(double x, double y) {
    return 0.5 * me * om * om * (x * x + y * y);
  }

  /**
   * Sets the (circular) frequency of the potential.
   */
  public void setOmega(double om) {
    this.om = om;
    if (field != null) {
      field.computeCachedMatrices();
    }
  }

  /**
   * Gets the (circular) frequency of the potential.
   */
  public double getOmega() {
    return om;
  }
}
