package physbeans.phys;

import physbeans.math.*;

/**
 * An InitializingWaveSource defines an initial value for the whole RippleTank.
 * <p>
 */
public abstract class InitializingWaveSource extends WaveSource {
  
  protected double t0;
  
  /** Creates a new instance of InitializingWaveSource */
  public InitializingWaveSource() {
    super();
    t0 = 0.0;
  }
  
  /**
   * At the initial time the whole grid of the RippleTank is set.
   */
  public void stirTank(RippleTank tank, double t) {
    
    
    if (! Maths.isZero(t - t0)) {
      return;
    }
    
    // everything is 0.0 by default
    double[][] grid = tank.getGrid();
    for (int x = 0; x < tank.getGridSizeX(); x++) {
      for (int y = 0; y < tank.getGridSizeY(); y++) {
        grid[y][x] = 0.0;
      }
    }
    
    setGrid(tank);
  }
  
  /**
   * Gets the value of the initial time.
   */
  public double getInitialTime() {
    return t0;
  }
  
  /**
   * Sets the value of the initial time.
   */
  public void setInitialTime(double t) {
    t0 = t;
  }
  
  abstract protected void setGrid(RippleTank tank);
}
