package physbeans.phys;

import physbeans.math.*;
import java.awt.*;

/**
 * A simple rectangular wall .
 */
public class RectangularWall extends WaveWall {
  
  protected DVector vllc, vruc;
  
  /** Creates a new instance of SimpleWall */
  public RectangularWall() {
    super();
    vllc = new DVector(-1.0, -1.0);
    vruc = new DVector(1.0, 1.0);
  }
  
  protected void setGrid() {
    if ((field == null) || (grid == null)) {
      return;
    }
    
    initGrid();
    
    Point llc = field.getIndex(vllc);
    Point ruc = field.getIndex(vruc);
    for (int y = ruc.y; y <= llc.y; y++) {
      grid[y][llc.x] = 1.0;
      grid[y][ruc.x] = 1.0;
    }
    
    for (int x = llc.x; x <= ruc.x; x++) {
      grid[llc.y][x] = 1.0;
      grid[ruc.y][x] = 1.0;
    }
    
    trigger();
  }
  
  
  /**
   * Gets the lower left corner of the wall.
   */
  public DVector getLowerLeftCorner() {
    return vllc;
  }
  
  /**
   * Sets the lower left corner of the wall.<br>
   * If the new position is to the right or upwards of the right upper corner,
   * the corresponding coordinates are swapped automatically.
   */
  public void setLowerLeftCorner(DVector v) {
    vllc.set(0, Math.min(v.x(), vruc.x()));
    vruc.set(0, Math.max(v.x(), vruc.x()));
    vllc.set(1, Math.min(v.y(), vruc.y()));
    vruc.set(1, Math.max(v.y(), vruc.y()));
    setGrid();
  }
  
  /**
   * Gets the upper right corner of the wall.
   */
  public DVector getUpperRightCorner() {
    return vruc;
  }
  
  /**
   * Sets the upper right corner of the wall.<br>
   * If the new position is to the left or downwards of the lower left corner,
   * the corresponding coordinates are swapped automatically.
   */
  public void setUpperRightCorner(DVector v) {
    vllc.set(0, Math.min(v.x(), vllc.x()));
    vruc.set(0, Math.max(v.x(), vllc.x()));
    vllc.set(1, Math.min(v.y(), vllc.y()));
    vruc.set(1, Math.max(v.y(), vllc.y()));
    setGrid();
  }
  
}
