package physbeans.phys;

/**
 * Base class of all wall configurations that can be set up in the ripple tank.
 * <P>Walls can define fixed or free ends of a wave (i.e they reflect without or
 * with a sign change).
 * <p>Children define a wall by setting a grid with values 1.0 (wall) and
 * 0.0 (no wall).
 */
public abstract class WaveWall extends WaveMedium {
  
  protected boolean freeEnd;
  
  /** Creates a new instance of WaveWall */
  public WaveWall() {
    super();
    freeEnd = false;
  }
  
  /**
   * Gets the value of the freeEnd flag.<br>
   * If true, waves are reflected with a sign change (like string waves at
   * a free end).
   */
  public boolean isFreeEnd() {
    return this.freeEnd;
  }
  
  /**
   * Sets the value of the freeEnd flag.<br>
   * If true, waves are reflected with a sign change (like string waves at
   * a free end).
   */
  public void setFreeEnd(boolean freeEnd) {
    this.freeEnd = freeEnd;
  }
}
