package physbeans.views;

import java.awt.*;
import java.awt.geom.*;
import java.io.*;

import physbeans.phys.*;
import physbeans.math.*;
import physbeans.model.*;

/**
 * Displays a glass plane.
 */
public class GlassPlaneView extends View {
  
  protected GlassPlane model;
  protected Color planeColor;
  
  /** Creates a new instance of VerticalGlassPlaneView */
  public GlassPlaneView() {
    planeColor = Color.WHITE;
  }
  
  /**
   * Gets the color of the plane.
   */
  public Color getPlaneColor() {
    return this.planeColor;
  }
  
  /**
   * Gets underlying model defining the glass plane to paint.
   */
  public GlassPlane getModel() {
    return model;
  }
  
  /**
   * Sets underlying model defining the glass plane to paint.
   */
  public void setModel(GlassPlane model) {
    this.model = model;
    update();
  }
  
  /**
   * Sets the color of the plane.
   */
  public void setPlaneColor(Color planeColor) {
    this.planeColor = planeColor;
  }
  
  public void paintLayer(Graphics2D g2) {
    if (model == null) {
      return;  // do nothing
    }
    
    Line2D l1, l2;
    Rectangle2D rect;
    if (model.isHorizontal()) {
      double xmax = trafo.getMaxWorld().get(0);
      double xmin = trafo.getMinWorld().get(0);
      double yu = model.getPosition() - model.getWidth()/2;
      double yo = model.getPosition() + model.getWidth()/2;
      
      l1 = new Line2D.Double(xmin, yu, xmax, yu);
      l2 = new Line2D.Double(xmin, yo, xmax, yo);
      rect = new Rectangle2D.Double(xmin, yu, xmax - xmin, yo - yu);
    } else {
      double ymax = trafo.getMaxWorld().get(1);
      double ymin = trafo.getMinWorld().get(1);
      double xl = model.getPosition() - model.getWidth()/2;
      double xr = model.getPosition() + model.getWidth()/2;
      
      l1 = new Line2D.Double(xl, ymin, xl, ymax);
      l2 = new Line2D.Double(xr, ymin, xr, ymax);
      rect = new Rectangle2D.Double(xl, ymin, xr - xl, ymax - ymin);
    }
    
    g2.setColor(planeColor);
    g2.fill(rect);
    g2.setColor(Color.black);
    g2.draw(l1);
    g2.draw(l2);
    
  }
}
