package physbeans.views;

import java.awt.*;

/**
 * Color table based on one color, that changes its lightness.<br>
 * It starts with black, reaches the given color in the middle and goes to
 * white - or the other way round in inverse mode.
 */
public class OneColorTable extends ColorTable {
  
  protected Color baseColor;
  protected boolean inverse;
  
  protected void defineRGBAValues() {
    float rb = baseColor.getRed();
    float gb = baseColor.getGreen();
    float bb = baseColor.getBlue();
    for (int i=0; i<128; i++) {
      r[i] = (byte) (i*rb/127.0);
      g[i] = (byte) (i*gb/127.0);
      b[i] = (byte) (i*bb/127.0);
    }
    
    for (int i=128; i<256; i++) {
      r[i] = (byte) (rb + (255-rb)*(i-127)/128.0);
      g[i] = (byte) (gb + (255-gb)*(i-127)/128.0);
      b[i] = (byte) (bb + (255-bb)*(i-127)/128.0);
    }
    
    if (inverse) {
      r = reverseTable(r);
      g = reverseTable(g);
      b = reverseTable(b);
    }
  }
  
  /**
   * Gets the basic color of the color table.
   */
  public Color getBaseColor() {
    return baseColor;
  }
  
  /**
   * Sets the basic color of the color table.
   */
  public void setbaseColor(Color c) {
    baseColor = c;
    defineRGBAValues();
    createTable();
  }
  
  /**
   * Gets the value of the inverse flag.
   */
  public boolean isInverse() {
    return inverse;
  }
  
  /**
   * Sets the value of the inverse flag.
   */
  public void setInverse(boolean b) {
    inverse = b;
    defineRGBAValues();
    createTable();
  }
  
  protected void initTables() {
    baseColor = Color.GREEN;
    inverse = false;
    super.initTables();
  }
  
  /**
   * Reverses the order of the table.
   */
  protected byte[] reverseTable(byte[] in) {
    int n = in.length;
    byte[] out = new byte[n];
    for (int i = 0; i < n; i++) {
      out[i] = in[n - 1 - i];
    }
    return out;
  }
}
