package physbeans.views;

import java.awt.*;
import java.awt.geom.*;
import java.io.*;
import physbeans.math.*;

/**
 * Displays a vector given by its start position, length and angle.
 */
public class SingleVectorView extends View implements Serializable {
  
  protected Color arrowColor;
  protected double arrowScale;
  protected double arrowTipLength;
  protected double arrowTipWidth;
  
  protected DVector position;
  protected double value;
  protected double angle;
  
  /**
   * create a standard horizontal SpringView
   */
  public SingleVectorView() {
    super();
    
    position = new DVector(2);
    value = 0.5;
    angle = 0.0;
    
    arrowColor = Color.red;
    arrowTipWidth = 0.1;
    arrowTipLength = 0.1;
    arrowScale = 0.5;
  }
  
  /**
   * Draws the vector.
   */
  public void paintLayer(Graphics2D g) {
    Color oldColor = g.getColor();
    g.setColor(arrowColor);
    
    //creates arrow of length=1
    GeneralPath arrow =new GeneralPath();  
    arrow.moveTo(0,0);
    arrow.lineTo(1,0);
    arrow.lineTo((float)(1-arrowTipWidth),(float)(-arrowTipLength));
    arrow.moveTo(1,0);
    arrow.lineTo((float)(1-arrowTipWidth),(float)arrowTipLength);
    
    AffineTransform scale = AffineTransform.getScaleInstance(arrowScale*value,arrowScale*value);
    arrow.transform(scale);
    
    AffineTransform rotate = AffineTransform.getRotateInstance(angle);
    arrow.transform(rotate);
    
    AffineTransform translate = AffineTransform.getTranslateInstance(position.x(),position.y());
    arrow.transform(translate);
      
    g.draw(arrow);
    g.setColor(oldColor);
  }
  
  /**
   * Gets value defining the length of the arrow.
   */
  public double getValue() {
    return value;
  }
  
  /**
   * Sets value defining the length of the arrow.
   */
  public void setValue(double value) {
    this.value = value;
  }
  
  /**
   * Gets angle of arrow measured counterclockwise against the x axis.
   */
  public double getAngle() {
    return angle;
  }
  
  /**
   * Sets angle of arrow measured counterclockwise against the x axis.
   */
  public void setAngle(double angle) {
    this.angle = angle;
  }
  
  /**
   * Gets start position of the vector.
   */
  public DVector getPosition() {
    return this.position;
  }
  
  /**
   * Sets start position of the vector.
   */
  public void setPosition(DVector position) {
    this.position = position;
  }
  
  /**
   * Gets the color of the force arrow.
   */
  public Color getArrowColor() {
    return this.arrowColor;
  }
  
  /**
   * Sets the color of the force arrow.
   */
  public void setArrowColor(Color arrowColor) {
    this.arrowColor = arrowColor;
  }
  
  /** Getter for property arrowScale.
   * @return Value of property arrowScale.
   */
  public double getArrowScale() {
    return this.arrowScale;
  }
  
  /** Setter for property arrowScale.
   * @param arrowScale New value of property arrowScale.
   */
  public void setArrowScale(double arrowScale) {
    this.arrowScale = arrowScale;
  }
  
  /**
   * gets length of arrow tip relative to arrow length
   */
  public double getArrowTipLength() {
    return this.arrowTipLength;
  }
  
  /**
   * sets length of arrow tip relative to arrow length
   */
  public void setArrowTipLength(double arrowTipLength) {
    this.arrowTipLength = arrowTipLength;
  }
  
  /**
   * gets width of arrow tip relative to arrow length
   */
  public double getArrowTipWidth() {
    return this.arrowTipWidth;
  }
  
  /**
   * sets width of arrow tip relative to arrow length
   */
  public void setArrowTipWidth(double arrowTipWidth) {
    this.arrowTipWidth = arrowTipWidth;
  }
}
